function [A,x,y] = Gauss2(dx,dy,sx,sy)
%function [A,x,y] = Gauss2(dx,dy,sx,sy)
%
%	dx - sample interval in x-direction
%	sx - standard deviation in x
%	dy - sample interval in y-direction
%	sy - standard deviation in y
%
%	Returns
%	A - Gaussian waveform
%	x - x-series for waveform which will be -round(sx*sqrt(20)):dx:round(sx*sqrt(20))
%	y - y-series for waveform which will be -round(sy*sqrt(20)):dy:round(sy*sqrt(20))
%	
%	NOTE:
%	The dominant period will be sx*sqrt(20)
%

Tx = round(sqrt(20)*sx);
Ty = round(sqrt(20)*sy);
x = -Tx:dx:Tx;
y = -Ty:dy:Ty;
A = ((1/(2*pi*sx*sy))*exp(-(1/2)*(x/sx).^2)'*exp(-(1/2)*(y/sy).^2))';
